pub struct AuCPaceServerRecvClientKey<D, const K1: usize>{ /* private fields */ }Expand description
Server in the CPace substep phase
Implementations
Sourceimpl<D, const K1: usize> AuCPaceServerRecvClientKey<D, K1>
impl<D, const K1: usize> AuCPaceServerRecvClientKey<D, K1>
Sourcepub fn receive_client_pubkey(
self,
client_pubkey: RistrettoPoint,
) -> Result<AuCPaceServerExpMutAuth<D, K1>>
pub fn receive_client_pubkey( self, client_pubkey: RistrettoPoint, ) -> Result<AuCPaceServerExpMutAuth<D, K1>>
Sourcepub fn implicit_auth(self, client_pubkey: RistrettoPoint) -> Result<SecretKey>
pub fn implicit_auth(self, client_pubkey: RistrettoPoint) -> Result<SecretKey>
Allow exiting the protocol early in the case of implicit authentication Note: this should only be used in special circumstances and the explicit mutual authentication stage should be used in all other cases
Arguments:
client_pubkey- the client’s public key
Return:
sk: the session key reached by the AuCPace protocol